import stringify from "json-stable-stringify";
import objectHash from "object-hash";
import { guilds, matches, tpMessages } from "~/drizzle/schema";
import { ExtractDataTypes, GetColumns } from "~/types/db";

export const buildMatches = (
  queryMatches: ExtractDataTypes<GetColumns<typeof matches>>[],
) =>
  queryMatches.map(
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    ({ id, guildId, utc_ts, ...match }) => ({
      ...match,
      utc_ts: utc_ts.toISOString(),
    }),
  );

export function buildConfig(
  guildQuery: ExtractDataTypes<GetColumns<typeof guilds>> & {
    tpMessages: ExtractDataTypes<GetColumns<typeof tpMessages>>[];
    matches: ExtractDataTypes<GetColumns<typeof matches>>[];
  },
) {
  const {
    id,
    timezone,
    tpEnabled,
    tpChannelId,
    tpInterval,
    tpRoles,
    isAvailableRoleId,
    wantsToBeNotifieRoledId,
  } = guildQuery;

  const targetMinute = tpInterval & 63;
  const targetHour = (tpInterval >> 6) & 31;
  const targetDay = (tpInterval >> 11) & 7;

  const payload = {
    guildId: id,
    timezone,
    features: {
      timePlanning: {
        enabled: tpEnabled,
        channelId: tpChannelId,
        targetMinute,
        targetHour,
        targetDay,
        roles: { enabled: tpRoles, isAvailableRoleId, wantsToBeNotifieRoledId },
      },
    },
    matches: buildMatches(guildQuery.matches),
    checksum: objectHash(stringify(guildQuery)),
  };
  return payload;
}
